"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ScriptFile = void 0;
const tslib_1 = require("tslib");
const typescript_1 = tslib_1.__importDefault(require("typescript"));
class ScriptFile {
    constructor(content, fileName, modifiedTime = new Date()) {
        this.content = content;
        this.fileName = fileName;
        this.modifiedTime = modifiedTime;
        this.originalContent = content;
    }
    write(content) {
        this.content = content;
        this.touch();
    }
    mutate(mutant) {
        this.guardMutationIsWatched();
        this.content = `${this.originalContent.substr(0, mutant.range[0])}${mutant.replacement}${this.originalContent.substr(mutant.range[1])}`;
        this.touch();
    }
    resetMutant() {
        this.guardMutationIsWatched();
        this.content = this.originalContent;
        this.touch();
    }
    guardMutationIsWatched() {
        if (!this.watcher) {
            throw new Error(`No watcher registered for ${this.fileName}. Changes would go unnoticed`);
        }
    }
    touch() {
        var _a;
        this.modifiedTime = new Date();
        (_a = this.watcher) === null || _a === void 0 ? void 0 : _a.call(this, this.fileName, typescript_1.default.FileWatcherEventKind.Changed);
    }
}
exports.ScriptFile = ScriptFile;
//# sourceMappingURL=script-file.js.map